@@ -7,13 +7,14 @@ struct Data {
 }
 
 fn main() {
-    App::build()
+    App::new()
         .add_plugins(DefaultPlugins)
         .add_plugin(InspectorPlugin::<Data>::new())
         .add_startup_system(setup.system())
         .run();
 }
 
+#[derive(Component)]
 struct Cube;
 
 fn setup(
@@ -37,7 +38,7 @@ fn setup(
         .insert(Cube)
         .id();
     data.cube = Some(cube);
-    commands.spawn_bundle(LightBundle {
+    commands.spawn_bundle(PointLightBundle {
         transform: Transform::from_xyz(4.0, 8.0, 4.0),
         ..Default::default()
     });
