@@ -1,10 +1,13 @@
+fn main() {}
+
+/*
 use bevy::prelude::*;
 use bevy_inspector_egui::WorldInspectorPlugin;
 use bevy_rapier2d::prelude::*;
 use bevy_rapier2d::rapier::na::Vector2;
 
 fn main() {
-    App::build()
+    App::new()
         .add_plugins(DefaultPlugins)
         .add_plugin(WorldInspectorPlugin::new())
         .add_startup_system(spawn_player.system())
@@ -81,3 +84,5 @@ fn player_movement(
         rb_vels.linvel = move_delta * player.0;
     }
 }
+
+*/
